#
# spec file for package spacewalk
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define release_name Smile

Name:           spacewalk
Version:        1.2.3
Release:        1.4
Summary:        Spacewalk Systems Management Application
Url:            https://fedorahosted.org/spacewalk
Group:          System/Management
License:        GPL v2 only
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Spacewalk is a systems management application that will inventory,
provision, update and control your Linux and Solaris machines.



%package common
Summary:        Spacewalk Systems Management Application with Oracle database backend
Group:          Applications/Internet
License:        GPL v2 only
Obsoletes:      spacewalk < 0.7.0

%if 0%{?suse_version}
Provides:       spacewalk
%endif

BuildRequires:  python
Requires:       python >= 2.3
Requires:       spacewalk-setup

# Java
Requires:       spacewalk-java
Requires:       spacewalk-taskomatic
Requires:       spacewalk-search

# Perl
Requires:       spacewalk-html
Requires:       spacewalk-base
Requires:       spacewalk-grail
Requires:       spacewalk-pxt
Requires:       spacewalk-sniglets

# Python
Requires:       spacewalk-certs-tools
Requires:       spacewalk-backend
Requires:       spacewalk-backend-app
Requires:       spacewalk-backend-applet
Requires:       spacewalk-backend-config-files
Requires:       spacewalk-backend-config-files-common
Requires:       spacewalk-backend-config-files-tool
Requires:       spacewalk-backend-iss
Requires:       spacewalk-backend-iss-export
Requires:       spacewalk-backend-package-push-server
Requires:       spacewalk-backend-tools
Requires:       spacewalk-backend-server
Requires:       spacewalk-backend-sql
Requires:       spacewalk-backend-xml-export-libs
Requires:       spacewalk-backend-xmlrpc
Requires:       spacewalk-backend-xp
Requires:       rhnpush

# Misc
Requires:       spacewalk-schema
Requires:       spacewalk-config
Requires:       yum-utils

# Requires:       osa-dispatcher
# Requires:       jabberpy

# Monitoring packages
Requires:       spacewalk-monitoring

# Solaris
# Requires:       rhn-solaris-bootstrap
# Requires:       rhn_solaris_bootstrap_5_1_0_3

# SELinux
%if 0%{?suse_version}
# don't use selinux
Requires:       osa-dispatcher
Requires:       susemanager-jsp_en
%else
Requires:       osa-dispatcher-selinux
Requires:       spacewalk-monitoring-selinux
Requires:       spacewalk-selinux
%endif

%if 0%{?fedora} >= 11 || 0%{?suse_version}
# Fedoras 11+ have their own selinux policy for jabberd - disable selinux on suse
%else
Requires:       jabberd-selinux
%endif

Requires:       editarea >= 0.8.2

%description common
Spacewalk is a systems management application that will inventory,
provision, update and control your Linux and Solaris machines.



%package oracle
Summary:        Spacewalk Systems Management Application with Oracle database backend
Group:          Applications/Internet
License:        GPL v2 only
Obsoletes:      spacewalk < 0.7.0
Requires:       spacewalk-common = %{version}-%{release}
Conflicts:      spacewalk-postgresql

Requires:       oracle-instantclient-basic >= 10.2.0
Requires:       oracle-instantclient-sqlplus >= 10.2.0
Requires:       spacewalk-java-oracle
Requires:       perl(DBD::Oracle)
Requires:       cx_Oracle
Requires:       spacewalk-backend-sql-oracle
Requires:       NOCpulsePlugins-Oracle
Requires:       perl-NOCpulse-Probe-Oracle
Requires:       quartz-oracle
# no SELinux
%if !0%{?suse_version}
Requires:       oracle-instantclient-selinux
Requires:       oracle-instantclient-sqlplus-selinux
%endif

%description oracle
Spacewalk is a systems management application that will inventory,
provision, update and control your Linux and Solaris machines.



%package postgresql
Summary:        Spacewalk Systems Management Application with PostgreSQL database backend
Group:          Applications/Internet
License:        GPL v2 only
Obsoletes:      spacewalk < 0.7.0
Requires:       spacewalk-common = %{version}-%{release}
Conflicts:      spacewalk-oracle

Requires:       spacewalk-java-postgresql
Requires:       perl(DBD::Pg)
Requires:       spacewalk-backend-sql-postgresql
Requires:       /usr/bin/psql

%description postgresql
Spacewalk is a systems management application that will inventory,
provision, update and control your Linux and Solaris machines.



%prep
#nothing to do here

%build
#nothing to do here

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT/%{_sysconfdir}
SW_REL=$(echo %{version} | awk -F. '{print $1"."$2}')
echo "Spacewalk release $SW_REL (%{release_name})" > $RPM_BUILD_ROOT/%{_sysconfdir}/spacewalk-release
install -d $RPM_BUILD_ROOT/%{_datadir}/spacewalk/setup/defaults.d
for i in oracle postgresql ; do
        cat <<EOF >$RPM_BUILD_ROOT/%{_datadir}/spacewalk/setup/defaults.d/$i-backend.conf
# database backend to be used by spacewalk
db-backend = $i
EOF
done

%clean
rm -rf %{buildroot}

%files common
%defattr(-,root,root)
%dir %{_datadir}/spacewalk
%dir %{_datadir}/spacewalk/setup
%dir %{_datadir}/spacewalk/setup/defaults.d
%{_sysconfdir}/spacewalk-release

%files oracle
%defattr(-,root,root)
%{_datadir}/spacewalk/setup/defaults.d/oracle-backend.conf

%files postgresql
%defattr(-,root,root)
%{_datadir}/spacewalk/setup/defaults.d/postgresql-backend.conf

%changelog
* Fri Jan 14 2011 mc@suse.de
- do not require a special release
* Fri Dec 10 2010 mc@suse.de
- require susemanager-jsp_en
* Wed Sep 22 2010 mantel@suse.de
- create build.py.props since package has not tarball but only spec
* Wed Sep 15 2010 mantel@suse.de
- Initial release of spacewalk
